/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */


//workaround to access protected functions
#define protected public

// default includes
#include <shiboken.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <pyside.h>
#include <typeresolver.h>
#include <typeinfo>
#include "pyside_qtscript_python.h"

#include "qscriptengineagent_wrapper.h"

// Extra includes
#include <qscriptengine.h>
#include <qscriptengineagent.h>
#include <qscriptvalue.h>


// Native ---------------------------------------------------------

QScriptEngineAgentWrapper::QScriptEngineAgentWrapper(QScriptEngine * engine) : QScriptEngineAgent(engine) {
    // ... middle
}

void QScriptEngineAgentWrapper::contextPop()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextPop"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptEngineAgent::contextPop();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QScriptEngineAgentWrapper::contextPush()
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "contextPush"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptEngineAgent::contextPush();
    }

    Shiboken::AutoDecRef pyargs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QScriptEngineAgentWrapper::exceptionCatch(qint64 scriptId, const QScriptValue & exception)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "exceptionCatch"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptEngineAgent::exceptionCatch(scriptId, exception);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(LN)",
        scriptId,
        Shiboken::Converter< ::QScriptValue >::toPython(exception)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QScriptEngineAgentWrapper::exceptionThrow(qint64 scriptId, const QScriptValue & exception, bool hasHandler)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "exceptionThrow"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptEngineAgent::exceptionThrow(scriptId, exception, hasHandler);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(LNN)",
        scriptId,
        Shiboken::Converter< ::QScriptValue >::toPython(exception),
        Shiboken::Converter< bool >::toPython(hasHandler)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

QVariant QScriptEngineAgentWrapper::extension(QScriptEngineAgent::Extension extension, const QVariant & argument)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return QVariant(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "extension"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptEngineAgent::extension(extension, argument);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(NN)",
        Shiboken::Converter< ::QScriptEngineAgent::Extension >::toPython(extension),
        Shiboken::Converter< QVariant >::toPython(argument)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return QVariant(0);
    }
    // Check return type
    bool typeIsValid = Shiboken::Converter< QVariant >::isConvertible(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptEngineAgent.extension", "QVariant", pyResult->ob_type->tp_name);
        return QVariant(0);
    }
    QVariant cppResult(Shiboken::Converter< QVariant >::toCpp(pyResult));
    return cppResult;
}

void QScriptEngineAgentWrapper::functionEntry(qint64 scriptId)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "functionEntry"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptEngineAgent::functionEntry(scriptId);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        scriptId
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QScriptEngineAgentWrapper::functionExit(qint64 scriptId, const QScriptValue & returnValue)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "functionExit"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptEngineAgent::functionExit(scriptId, returnValue);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(LN)",
        scriptId,
        Shiboken::Converter< ::QScriptValue >::toPython(returnValue)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QScriptEngineAgentWrapper::positionChange(qint64 scriptId, int lineNumber, int columnNumber)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "positionChange"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptEngineAgent::positionChange(scriptId, lineNumber, columnNumber);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(Lii)",
        scriptId,
        lineNumber,
        columnNumber
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QScriptEngineAgentWrapper::scriptLoad(qint64 id, const QString & program, const QString & fileName, int baseLineNumber)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "scriptLoad"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptEngineAgent::scriptLoad(id, program, fileName, baseLineNumber);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(LNNi)",
        id,
        Shiboken::Converter< QString >::toPython(program),
        Shiboken::Converter< QString >::toPython(fileName),
        baseLineNumber
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

void QScriptEngineAgentWrapper::scriptUnload(qint64 id)
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return ;
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "scriptUnload"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptEngineAgent::scriptUnload(id);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(L)",
        id
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return ;
    }
}

bool QScriptEngineAgentWrapper::supportsExtension(QScriptEngineAgent::Extension extension) const
{
    Shiboken::GilState gil;
    if (PyErr_Occurred())
        return bool(0);
    Shiboken::AutoDecRef py_override(Shiboken::BindingManager::instance().getOverride(this, "supportsExtension"));
    if (py_override.isNull()) {
        gil.release();
        return this->::QScriptEngineAgent::supportsExtension(extension);
    }

    Shiboken::AutoDecRef pyargs(Py_BuildValue("(N)",
        Shiboken::Converter< ::QScriptEngineAgent::Extension >::toPython(extension)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(py_override, pyargs, NULL));
    // An error happened in python code!
    if (pyResult.isNull()) {
        PyErr_Print();
        return bool(0);
    }
    // Check return type
    bool typeIsValid = PyBool_Check(pyResult);
    if (!typeIsValid) {
        PyErr_Format(PyExc_TypeError, "Invalid return value in function %s, expected %s, got %s.", "QScriptEngineAgent.supportsExtension", "bool", pyResult->ob_type->tp_name);
        return bool(0);
    }
    bool cppResult(Shiboken::Converter< bool >::toCpp(pyResult));
    return cppResult;
}

QScriptEngineAgentWrapper::~QScriptEngineAgentWrapper()
{
    SbkObject* wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QScriptEngineAgent_Init(PyObject* self, PyObject* args, PyObject* kwds)
{
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType<QScriptEngineAgent >()))
        return -1;

    QScriptEngineAgentWrapper* cptr = 0;
    int overloadId = -1;
    SbkObject* sbkSelf = reinterpret_cast<SbkObject*>(self);


    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "QScriptEngineAgent", 1, 1, &(pyargs[0])))
        return -1;

    // Overloaded function decisor
    // 0: QScriptEngineAgent(QScriptEngine*)
    if (numArgs == 1 && Shiboken::Converter< ::QScriptEngine * >::isConvertible(pyargs[0])) {
        overloadId = 0; // QScriptEngineAgent(QScriptEngine*)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineAgent_Init_TypeError;

    // Call function/method
    {
        {
            if (!Shiboken::Object::isValid(pyargs[0]))
                return -1;
            QScriptEngine * cppArg0 = Shiboken::Converter<QScriptEngine * >::toCpp(pyargs[0]);

            if(!PyErr_Occurred()) {
                // QScriptEngineAgent(QScriptEngine*)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cptr = new QScriptEngineAgentWrapper(cppArg0);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }

    if (PyErr_Occurred() || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType<QScriptEngineAgent >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (!cptr) goto Sbk_QScriptEngineAgent_Init_TypeError;

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;

    Sbk_QScriptEngineAgent_Init_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptEngine", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent", overloads);
        return -1;
}

static PyObject* Sbk_QScriptEngineAgentFunc_contextPop(PyObject* self)
{
    QScriptEngineAgent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineAgent* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // contextPop()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QScriptEngineAgent::contextPop() : cppSelf->contextPop());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptEngineAgentFunc_contextPush(PyObject* self)
{
    QScriptEngineAgent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineAgent* >::toCpp(self);


    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // contextPush()
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QScriptEngineAgent::contextPush() : cppSelf->contextPush());
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;
}

static PyObject* Sbk_QScriptEngineAgentFunc_engine(PyObject* self)
{
    QScriptEngineAgent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineAgent* >::toCpp(self);

    PyObject* pyResult = 0;

    // Call function/method
    {
        {

            if(!PyErr_Occurred()) {
                // engine()const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QScriptEngine * cppResult = const_cast<const QScriptEngineAgent*>(cppSelf)->engine();
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< ::QScriptEngine * >::toPython(cppResult);
                Shiboken::Object::setParent(self, pyResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;
}

static PyObject* Sbk_QScriptEngineAgentFunc_exceptionCatch(PyObject* self, PyObject* args)
{
    QScriptEngineAgent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "exceptionCatch", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: exceptionCatch(qint64,QScriptValue)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QScriptValue >::isConvertible(pyargs[1])) {
        overloadId = 0; // exceptionCatch(qint64,QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineAgentFunc_exceptionCatch_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QScriptValue cppArg1 = Shiboken::Converter<QScriptValue >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // exceptionCatch(qint64,QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QScriptEngineAgent::exceptionCatch(cppArg0, cppArg1) : cppSelf->exceptionCatch(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineAgentFunc_exceptionCatch_TypeError:
        const char* overloads[] = {"long long, PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent.exceptionCatch", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineAgentFunc_exceptionThrow(PyObject* self, PyObject* args)
{
    QScriptEngineAgent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "exceptionThrow", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: exceptionThrow(qint64,QScriptValue,bool)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QScriptValue >::isConvertible(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // exceptionThrow(qint64,QScriptValue,bool)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineAgentFunc_exceptionThrow_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QScriptValue cppArg1 = Shiboken::Converter<QScriptValue >::toCpp(pyargs[1]);
            bool cppArg2 = Shiboken::Converter<bool >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // exceptionThrow(qint64,QScriptValue,bool)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QScriptEngineAgent::exceptionThrow(cppArg0, cppArg1, cppArg2) : cppSelf->exceptionThrow(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineAgentFunc_exceptionThrow_TypeError:
        const char* overloads[] = {"long long, PySide.QtScript.QScriptValue, bool", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent.exceptionThrow", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineAgentFunc_extension(PyObject* self, PyObject* args, PyObject* kwds)
{
    QScriptEngineAgent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineAgent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;
    int numNamedArgs = (kwds ? PyDict_Size(kwds) : 0);
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths
    if (numArgs + numNamedArgs > 2) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngineAgent.extension(): too many arguments");
        return 0;
    } else if (numArgs < 1) {
        PyErr_SetString(PyExc_TypeError, "PySide.QtScript.QScriptEngineAgent.extension(): not enough arguments");
        return 0;
    }

    if (!PyArg_ParseTuple(args, "|OO:extension", &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: extension(QScriptEngineAgent::Extension,QVariant)
    if (Shiboken::Converter< ::QScriptEngineAgent::Extension >::isConvertible(pyargs[0])) {
        if (numArgs == 1) {
            overloadId = 0; // extension(QScriptEngineAgent::Extension,QVariant)
        } else if (Shiboken::Converter< QVariant >::isConvertible(pyargs[1])) {
            overloadId = 0; // extension(QScriptEngineAgent::Extension,QVariant)
        }
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineAgentFunc_extension_TypeError;

    // Call function/method
    {
        {
            if (kwds) {
                const char* errorArgName = 0;
                PyObject* value = PyDict_GetItemString(kwds, "argument");
                if (value) {
                    if (pyargs[1])
                        errorArgName = "argument";
                    else if (Shiboken::Converter< QVariant >::isConvertible(value))
                        pyargs[1] = value;
                    else
                        goto Sbk_QScriptEngineAgentFunc_extension_TypeError;
                }
                if (errorArgName) {
                    PyErr_Format(PyExc_TypeError, "PySide.QtScript.QScriptEngineAgent.extension(): got multiple values for keyword argument '%s'", errorArgName);
                    return 0;
                }
            }
            QScriptEngineAgent::Extension cppArg0 = Shiboken::Converter<QScriptEngineAgent::Extension >::toCpp(pyargs[0]);
            QVariant cppArg1 = pyargs[1] ? Shiboken::Converter<QVariant >::toCpp(pyargs[1]) : QVariant();

            if(!PyErr_Occurred()) {
                // extension(QScriptEngineAgent::Extension,QVariant)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                QVariant cppResult = (Shiboken::Object::isUserType(self) ? cppSelf->::QScriptEngineAgent::extension(cppArg0, cppArg1) : cppSelf->extension(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< QVariant >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineAgentFunc_extension_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptEngineAgent.Extension, QVariant = QVariant()", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent.extension", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineAgentFunc_functionEntry(PyObject* self, PyObject* arg)
{
    QScriptEngineAgent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: functionEntry(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // functionEntry(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineAgentFunc_functionEntry_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // functionEntry(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QScriptEngineAgent::functionEntry(cppArg0) : cppSelf->functionEntry(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineAgentFunc_functionEntry_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngineAgent.functionEntry", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineAgentFunc_functionExit(PyObject* self, PyObject* args)
{
    QScriptEngineAgent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "functionExit", 2, 2, &(pyargs[0]), &(pyargs[1])))
        return 0;


    // Overloaded function decisor
    // 0: functionExit(qint64,QScriptValue)
    if (numArgs == 2 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< ::QScriptValue >::isConvertible(pyargs[1])) {
        overloadId = 0; // functionExit(qint64,QScriptValue)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineAgentFunc_functionExit_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);
            if (!Shiboken::Object::isValid(pyargs[1]))
                return 0;
            QScriptValue cppArg1 = Shiboken::Converter<QScriptValue >::toCpp(pyargs[1]);

            if(!PyErr_Occurred()) {
                // functionExit(qint64,QScriptValue)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QScriptEngineAgent::functionExit(cppArg0, cppArg1) : cppSelf->functionExit(cppArg0, cppArg1));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineAgentFunc_functionExit_TypeError:
        const char* overloads[] = {"long long, PySide.QtScript.QScriptValue", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent.functionExit", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineAgentFunc_positionChange(PyObject* self, PyObject* args)
{
    QScriptEngineAgent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "positionChange", 3, 3, &(pyargs[0]), &(pyargs[1]), &(pyargs[2])))
        return 0;


    // Overloaded function decisor
    // 0: positionChange(qint64,int,int)
    if (numArgs == 3 && SbkNumber_Check(pyargs[0]) && SbkNumber_Check(pyargs[1]) && SbkNumber_Check(pyargs[2])) {
        overloadId = 0; // positionChange(qint64,int,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineAgentFunc_positionChange_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);
            int cppArg1 = Shiboken::Converter<int >::toCpp(pyargs[1]);
            int cppArg2 = Shiboken::Converter<int >::toCpp(pyargs[2]);

            if(!PyErr_Occurred()) {
                // positionChange(qint64,int,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QScriptEngineAgent::positionChange(cppArg0, cppArg1, cppArg2) : cppSelf->positionChange(cppArg0, cppArg1, cppArg2));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineAgentFunc_positionChange_TypeError:
        const char* overloads[] = {"long long, int, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent.positionChange", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineAgentFunc_scriptLoad(PyObject* self, PyObject* args)
{
    QScriptEngineAgent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;
    int numArgs = PyTuple_GET_SIZE(args);
    PyObject* pyargs[] = {0, 0, 0, 0};

    // invalid argument lengths


    if (!PyArg_UnpackTuple(args, "scriptLoad", 4, 4, &(pyargs[0]), &(pyargs[1]), &(pyargs[2]), &(pyargs[3])))
        return 0;


    // Overloaded function decisor
    // 0: scriptLoad(qint64,QString,QString,int)
    if (numArgs == 4 && SbkNumber_Check(pyargs[0]) && Shiboken::Converter< QString >::isConvertible(pyargs[1]) && Shiboken::Converter< QString >::isConvertible(pyargs[2]) && SbkNumber_Check(pyargs[3])) {
        overloadId = 0; // scriptLoad(qint64,QString,QString,int)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineAgentFunc_scriptLoad_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(pyargs[0]);
            QString cppArg1 = Shiboken::Converter<QString >::toCpp(pyargs[1]);
            QString cppArg2 = Shiboken::Converter<QString >::toCpp(pyargs[2]);
            int cppArg3 = Shiboken::Converter<int >::toCpp(pyargs[3]);

            if(!PyErr_Occurred()) {
                // scriptLoad(qint64,QString,QString,int)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QScriptEngineAgent::scriptLoad(cppArg0, cppArg1, cppArg2, cppArg3) : cppSelf->scriptLoad(cppArg0, cppArg1, cppArg2, cppArg3));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineAgentFunc_scriptLoad_TypeError:
        const char* overloads[] = {"long long, QString, QString, int", 0};
        Shiboken::setErrorAboutWrongArguments(args, "PySide.QtScript.QScriptEngineAgent.scriptLoad", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineAgentFunc_scriptUnload(PyObject* self, PyObject* arg)
{
    QScriptEngineAgent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineAgent* >::toCpp(self);

    int overloadId = -1;

    // Overloaded function decisor
    // 0: scriptUnload(qint64)
    if (SbkNumber_Check(arg)) {
        overloadId = 0; // scriptUnload(qint64)
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineAgentFunc_scriptUnload_TypeError;

    // Call function/method
    {
        {
            qint64 cppArg0 = Shiboken::Converter<qint64 >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // scriptUnload(qint64)
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                (Shiboken::Object::isUserType(self) ? cppSelf->::QScriptEngineAgent::scriptUnload(cppArg0) : cppSelf->scriptUnload(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
        }
    }


    if (PyErr_Occurred()) {
        return 0;
    }
    Py_RETURN_NONE;

    Sbk_QScriptEngineAgentFunc_scriptUnload_TypeError:
        const char* overloads[] = {"long long", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngineAgent.scriptUnload", overloads);
        return 0;
}

static PyObject* Sbk_QScriptEngineAgentFunc_supportsExtension(PyObject* self, PyObject* arg)
{
    QScriptEngineAgent* cppSelf = 0;
    if (!Shiboken::Object::isValid(self))
        return 0;
    cppSelf = Shiboken::Converter< QScriptEngineAgent* >::toCpp(self);

    PyObject* pyResult = 0;
    int overloadId = -1;

    // Overloaded function decisor
    // 0: supportsExtension(QScriptEngineAgent::Extension)const
    if (Shiboken::Converter< ::QScriptEngineAgent::Extension >::isConvertible(arg)) {
        overloadId = 0; // supportsExtension(QScriptEngineAgent::Extension)const
    }

    // Function signature not found.
    if (overloadId == -1) goto Sbk_QScriptEngineAgentFunc_supportsExtension_TypeError;

    // Call function/method
    {
        {
            QScriptEngineAgent::Extension cppArg0 = Shiboken::Converter<QScriptEngineAgent::Extension >::toCpp(arg);

            if(!PyErr_Occurred()) {
                // supportsExtension(QScriptEngineAgent::Extension)const
                PyThreadState* _save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                bool cppResult = (Shiboken::Object::isUserType(self) ? const_cast<const QScriptEngineAgent*>(cppSelf)->::QScriptEngineAgent::supportsExtension(cppArg0) : const_cast<const QScriptEngineAgent*>(cppSelf)->supportsExtension(cppArg0));
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
                pyResult = Shiboken::Converter< bool >::toPython(cppResult);
            }
        }
    }


    if (PyErr_Occurred() || !pyResult) {
        Py_XDECREF(pyResult);
        return 0;
    }
    return pyResult;

    Sbk_QScriptEngineAgentFunc_supportsExtension_TypeError:
        const char* overloads[] = {"PySide.QtScript.QScriptEngineAgent.Extension", 0};
        Shiboken::setErrorAboutWrongArguments(arg, "PySide.QtScript.QScriptEngineAgent.supportsExtension", overloads);
        return 0;
}

static PyMethodDef Sbk_QScriptEngineAgent_methods[] = {
    {"contextPop", (PyCFunction)Sbk_QScriptEngineAgentFunc_contextPop, METH_NOARGS},
    {"contextPush", (PyCFunction)Sbk_QScriptEngineAgentFunc_contextPush, METH_NOARGS},
    {"engine", (PyCFunction)Sbk_QScriptEngineAgentFunc_engine, METH_NOARGS},
    {"exceptionCatch", (PyCFunction)Sbk_QScriptEngineAgentFunc_exceptionCatch, METH_VARARGS},
    {"exceptionThrow", (PyCFunction)Sbk_QScriptEngineAgentFunc_exceptionThrow, METH_VARARGS},
    {"extension", (PyCFunction)Sbk_QScriptEngineAgentFunc_extension, METH_VARARGS|METH_KEYWORDS},
    {"functionEntry", (PyCFunction)Sbk_QScriptEngineAgentFunc_functionEntry, METH_O},
    {"functionExit", (PyCFunction)Sbk_QScriptEngineAgentFunc_functionExit, METH_VARARGS},
    {"positionChange", (PyCFunction)Sbk_QScriptEngineAgentFunc_positionChange, METH_VARARGS},
    {"scriptLoad", (PyCFunction)Sbk_QScriptEngineAgentFunc_scriptLoad, METH_VARARGS},
    {"scriptUnload", (PyCFunction)Sbk_QScriptEngineAgentFunc_scriptUnload, METH_O},
    {"supportsExtension", (PyCFunction)Sbk_QScriptEngineAgentFunc_supportsExtension, METH_O},

    {0} // Sentinel
};

} // extern "C"

// Class Definition -----------------------------------------------
extern "C" {
static SbkObjectType Sbk_QScriptEngineAgent_Type = { { {
    PyObject_HEAD_INIT(&SbkObjectType_Type)
    /*ob_size*/             0,
    /*tp_name*/             "PySide.QtScript.QScriptEngineAgent",
    /*tp_basicsize*/        sizeof(SbkObject),
    /*tp_itemsize*/         0,
    /*tp_dealloc*/          &SbkDeallocWrapper,
    /*tp_print*/            0,
    /*tp_getattr*/          0,
    /*tp_setattr*/          0,
    /*tp_compare*/          0,
    /*tp_repr*/             0,
    /*tp_as_number*/        0,
    /*tp_as_sequence*/      0,
    /*tp_as_mapping*/       0,
    /*tp_hash*/             0,
    /*tp_call*/             0,
    /*tp_str*/              0,
    /*tp_getattro*/         0,
    /*tp_setattro*/         0,
    /*tp_as_buffer*/        0,
    /*tp_flags*/            Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_CHECKTYPES,
    /*tp_doc*/              0,
    /*tp_traverse*/         0,
    /*tp_clear*/            0,
    /*tp_richcompare*/      0,
    /*tp_weaklistoffset*/   0,
    /*tp_iter*/             0,
    /*tp_iternext*/         0,
    /*tp_methods*/          Sbk_QScriptEngineAgent_methods,
    /*tp_members*/          0,
    /*tp_getset*/           0,
    /*tp_base*/             reinterpret_cast<PyTypeObject*>(&SbkObject_Type),
    /*tp_dict*/             0,
    /*tp_descr_get*/        0,
    /*tp_descr_set*/        0,
    /*tp_dictoffset*/       0,
    /*tp_init*/             Sbk_QScriptEngineAgent_Init,
    /*tp_alloc*/            0,
    /*tp_new*/              SbkObjectTpNew,
    /*tp_free*/             0,
    /*tp_is_gc*/            0,
    /*tp_bases*/            0,
    /*tp_mro*/              0,
    /*tp_cache*/            0,
    /*tp_subclasses*/       0,
    /*tp_weaklist*/         0
}, },
    /*priv_data*/           0
};
} //extern


void init_QScriptEngineAgent(PyObject* module)
{
    SbkPySide_QtScriptTypes[SBK_QSCRIPTENGINEAGENT_IDX] = reinterpret_cast<PyTypeObject*>(&Sbk_QScriptEngineAgent_Type);

    Shiboken::ObjectType::initPrivateData(&Sbk_QScriptEngineAgent_Type);
    Shiboken::ObjectType::setDestructorFunction(&Sbk_QScriptEngineAgent_Type, &Shiboken::callCppDestructor<QScriptEngineAgent >);
    Py_INCREF((PyObject*)&Sbk_QScriptEngineAgent_Type); //Incref due the 'PyModule_AddObject' steals the reference.
    if (PyType_Ready((PyTypeObject*)&Sbk_QScriptEngineAgent_Type) < 0)
        return;

    // Fill type discovery information

    Shiboken::ObjectType::setOriginalName(&Sbk_QScriptEngineAgent_Type, "QScriptEngineAgent*");
    PyModule_AddObject(module, "QScriptEngineAgent",
        ((PyObject*)&Sbk_QScriptEngineAgent_Type));

    // Initialize enums
    PyObject* enumItem;

    // init enum: Extension
    PyTypeObject* SbkPySide_QtScript_QScriptEngineAgent_Extension = Shiboken::Enum::newType("PySide.QtScript.QScriptEngineAgent.Extension");
    SbkPySide_QtScriptTypes[SBK_QSCRIPTENGINEAGENT_EXTENSION_IDX] = SbkPySide_QtScript_QScriptEngineAgent_Extension;
    if (PyType_Ready(SbkPySide_QtScript_QScriptEngineAgent_Extension) < 0)
        return;
    PyDict_SetItemString(Sbk_QScriptEngineAgent_Type.super.ht_type.tp_dict,
            "Extension",((PyObject*)SbkPySide_QtScript_QScriptEngineAgent_Extension));

    enumItem = Shiboken::Enum::newItem(SbkPySide_QtScript_QScriptEngineAgent_Extension,(long) QScriptEngineAgent::DebuggerInvocationRequest, "DebuggerInvocationRequest");
    PyDict_SetItemString(Sbk_QScriptEngineAgent_Type.super.ht_type.tp_dict,"DebuggerInvocationRequest", enumItem);
    Py_DECREF(enumItem);
    PyDict_SetItemString(SbkPySide_QtScript_QScriptEngineAgent_Extension->tp_dict,"DebuggerInvocationRequest", enumItem);
    Py_DECREF(enumItem);
    Shiboken::TypeResolver::createValueTypeResolver<int>("QScriptEngineAgent::Extension");
    Shiboken::TypeResolver::createValueTypeResolver<int>("::Extension");
    // end of enum Extension


    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngineAgent >("QScriptEngineAgent*");
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngineAgent >(typeid(QScriptEngineAgent).name());
    Shiboken::TypeResolver::createObjectTypeResolver<QScriptEngineAgent >(typeid(QScriptEngineAgentWrapper).name());
    qRegisterMetaType< ::QScriptEngineAgent* >("QScriptEngineAgent*");
    qRegisterMetaType< ::QScriptEngineAgent::Extension >("QScriptEngineAgent::Extension");
}

